// Copyright 2008, Massachusetts Institute of Technology.
// The use of this code is permitted for research only. There is
// absolutely no warranty for this software.
//
// Author: John Lee (jjl@mit.edu)
//
// Given a set of files with Pyramids, computes the PMK for each of
// them and accumulates (sums up) their results. This does NOT normalize
// the resulting kernel.
//

#include <stdio.h>
#include <math.h>
#include <iostream>
#include <fstream>
#include "histograms/multi-resolution-histogram.h"
#include "pyramids/pyramid-matcher.h"
#include "kernel/kernel-matrix.h"
#include "util/bin-weight-scheme.h"

using namespace std;
using namespace libpmk;
using namespace libpmk_util;

void usage(const char* exec_name) {
  cerr << "Usage: " << exec_name << " output.kern input1.mrh input2.mrh ..\n";
  cerr << "<ouput.kern>:  Where to write unnormalized kernel to\n";
  cerr << "<inputs.mrh>: input pyramids\n";
}

int main(int argc, char** argv) {
  if (argc < 3) {
    usage(argv[0]);
    exit(0);
  }

  string output_file(argv[1]);

  KernelMatrix km;
  for (int ii = 2; ii < argc; ++ii) {
    string input_file(argv[ii]);
    cout << "Reading pyramids from " << input_file << "... " << flush;
    vector<MultiResolutionHistogram*>
      vec(MultiResolutionHistogram::ReadFromFile(input_file.c_str()));
    cout << "done." << endl;

    km.Resize((int)vec.size());
    for (int ii = 0; ii < (int)vec.size(); ++ii) {

      for (int jj = 0; jj <= ii; ++jj) {
        km.at(ii, jj) +=
          PyramidMatcher::GetPyramidMatchSimilarity(*vec[ii], *vec[jj],
                                                    BIN_WEIGHT_GLOBAL);
      }
    }

    for (int ii = 0; ii < (int)vec.size(); ++ii) {
      delete vec[ii];
    }
  }
  
  cout << "Writing kernel to " << output_file << "... " << flush;
  km.WriteToFile(output_file.c_str());
  cout << "done." << endl;
  
  return 0;
}
